HotGraphicsPipeline

Struct HotGraphicsPipeline 

pub struct HotGraphicsPipeline { /* private fields */ }
A graphics pipeline wrapper that recompiles its shaders when source files change.

Implementations

Source

impl HotGraphicsPipeline

pub fn create<S>( device: &Device, info: impl Into<GraphicsPipelineInfo>, shaders: impl IntoIterator<Item = S>, ) -> Result<Self, DriverError>
where S: Into<HotShader>,

Creates a hot-reload graphics pipeline from one or more shader files.

Source

impl HotGraphicsPipeline

pub fn device(&self) -> &Device

The device which owns this pipeline.

pub fn info(&self) -> GraphicsPipelineInfo

Gets the information used to create this object.

pub fn set_debug_name(&self, name: impl AsRef<str>)

Sets the debugging name assigned to this pipeline.

Note: The pipeline name may only be assigned once. Subsequent calls will not update the previously set name value.

pub fn with_debug_name(self, name: impl AsRef<str>) -> Self

Sets the debugging name assigned to this pipeline.

Note: The pipeline name may only be assigned once. Subsequent calls will not update the previously set name value.