pub struct HotGraphicsPipeline { /* private fields */ }Expand description
A graphics pipeline wrapper that recompiles its shaders when source files change.
Implementations
Sourceimpl HotGraphicsPipeline
impl HotGraphicsPipeline
Sourcepub fn create<S>(
device: &Device,
info: impl Into<GraphicsPipelineInfo>,
shaders: impl IntoIterator<Item = S>,
) -> Result<Self, DriverError>
pub fn create<S>( device: &Device, info: impl Into<GraphicsPipelineInfo>, shaders: impl IntoIterator<Item = S>, ) -> Result<Self, DriverError>
Creates a hot-reload graphics pipeline from one or more shader files.
Sourceimpl HotGraphicsPipeline
impl HotGraphicsPipeline
Sourcepub fn info(&self) -> GraphicsPipelineInfo
pub fn info(&self) -> GraphicsPipelineInfo
Gets the information used to create this object.
Sourcepub fn set_debug_name(&self, name: impl AsRef<str>)
pub fn set_debug_name(&self, name: impl AsRef<str>)
Sets the debugging name assigned to this pipeline.
Note: The pipeline name may only be assigned once. Subsequent calls will not update the previously set name value.
Sourcepub fn with_debug_name(self, name: impl AsRef<str>) -> Self
pub fn with_debug_name(self, name: impl AsRef<str>) -> Self
Sets the debugging name assigned to this pipeline.
Note: The pipeline name may only be assigned once. Subsequent calls will not update the previously set name value.